IosZjExposureFailureCode enum
Values
- Other → const IosZjExposureFailureCode
-
const IosZjExposureFailureCode(0) - MediaBasePriceFilter → const IosZjExposureFailureCode
-
const IosZjExposureFailureCode(1) - BidFailed → const IosZjExposureFailureCode
-
const IosZjExposureFailureCode(2) - CacheInvalid → const IosZjExposureFailureCode
-
const IosZjExposureFailureCode(3) - PriorityReduce → const IosZjExposureFailureCode
-
const IosZjExposureFailureCode(4) - ReturnTimeout → const IosZjExposureFailureCode
-
const IosZjExposureFailureCode(5) - MediaBlocking → const IosZjExposureFailureCode
-
const IosZjExposureFailureCode(6)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
IosZjExposureFailureCode> - A constant List of the values in this enum, in order of their declaration.